@@ -34,6 +34,16 @@ _CONFIGS = {
          'label_shape_color': 'content_class'.split(','),
          'default_label': json.dumps({'text': '', 'content_class': '其它类', 'content_kv': 'value'}, ensure_ascii=False),
          },
+    '三码合一入学判定':
+        {'_attrs':
+             [['text', 1, 'str'],
+              ["class", 1, "str", ("姓名", "身份证", "联系方式", "采样时间", "检测时间", "核酸结果",
+                                   "14天经过或途经", "健康码颜色", "其他类")],
+              ['kv', 1, 'str', ('key', 'value')],
+              ],
+         'label_shape_color': 'content_class'.split(','),
+         'default_label': json.dumps({'text': '', 'class': '其它类', 'kv': 'value'}, ensure_ascii=False),
+         },
     'XlCoco': {
         '_attrs':
             [['id', 1, 'int'],
